@@ -468,8 +468,11 @@ With prefix ARG, insert output into the current buffer at point."
 		;; cause the output buffer to take up as little screen
 		;; real-estate as possible, if temp buffer resizing is
 		;; enabled
-		(and intr temp-buffer-resize-mode
-		     (resize-temp-buffer-window)))))))))))
+		(and intr (if (featurep 'xemacs)
+                              (and temp-buffer-shrink-to-fit
+                                   (shrink-window-if-larger-than-buffer))
+                            (and temp-buffer-resize-mode
+                                 (resize-temp-buffer-window)))))))))))))
 
 ;;;###autoload
 (defun eshell-command-result (command &optional status-var)
